# LeNet with batch normalization model definition
import sys

# LeNet model definition (batch normalization version)
def LeNet_Model(s):
   
   # instantiate model
   s.buildModel(model=dict(name='LeNet',replace=True),type='CNN')

   # input layer
   s.addLayer(model='LeNet', name='mnist',
              layer=dict( type='input', nchannels=1, width=28, height=28,
              scale=0.00392156862745098039))

   # conv1: 5*5*20
   s.addLayer(model='LeNet', name='conv1',
              layer=dict( type='convolution', nFilters=20, width=5, height=5, 
                          stride=1, act='identity', noBias=True, init='xavier'), 
              srcLayers=['mnist'])

   # conv1 batch normalization
   s.addLayer(model='LeNet', name='conv1_bn',
              layer=dict( type='batchnorm', act='relu'), srcLayers=['conv1'])

   # pool1 2*2*2
   s.addLayer(model='LeNet', name='pool1',
              layer=dict(type='pooling',width=2, height=2, stride=2, pool='max'), 
              srcLayers=['conv1_bn'])

   # conv2: 5*5*50
   s.addLayer(model='LeNet', name='conv2',
              layer=dict( type='convolution', nFilters=50, width=5, height=5, 
                          stride=1, act='identity', noBias=True, init='xavier'), 
              srcLayers=['pool1'])

   # conv2 batch normalization
   s.addLayer(model='LeNet', name='conv2_bn',
              layer=dict( type='batchnorm', act='relu'), srcLayers=['conv2'])

   # pool2 2*2*2
   s.addLayer(model='LeNet', name='pool2',
              layer=dict(type='pooling',width=2, height=2, stride=2, pool='max'), 
              srcLayers=['conv2_bn'])

   # fully connected layer
   s.addLayer(model='LeNet', name='ip1',
              layer=dict(type='fullconnect',n=500, init='xavier', act='relu'), 
              srcLayers=['pool2'])

   # output layer
   s.addLayer(model='LeNet', name='ip2',
              layer=dict(type='output',n=10, init='xavier', act='softmax'), 
              srcLayers=['ip1'])

#########################################################################################
if __name__ == "__main__":
   sys.exit("ERROR: this module defines the LeNet model.  Do not call directly.")