    BuildModel/model={name='ResNet152', replace=1} type = "CNN";
    run;
 
    /* input layer */
    AddLayer/model='ResNet152' name="data" 
             layer={type='input' nchannels=3 width=224 height=224 randomcrop='UNIQUE' offsets={103.939, 116.779, 123.68}};
    run;
 
    /* -------------------- Layer 1 ---------------------- */
    
    /* conv1 layer: 64 channels, 7x7 conv, stride=2; output = 112 x 112 */
    AddLayer/model='ResNet152' name="conv1" 
            layer={type='convolution' nFilters=64 width=7 height=7 stride=2 act="IDENTITY"} srcLayers={"data"};
    run;
 
    /* conv1 batch norm layer: 64 channels, output = 112 x 112 */
    AddLayer/model='ResNet152' name="bn_conv1"
            layer={type='batchnorm' act='RELU'} srcLayers={"conv1"};
    run;

    /* pool1 layer: 64 channels, 3x3 pooling, output = 56 x 56 */
    AddLayer/model='ResNet152' name="pool1" 
            layer={type='pooling' width=3 height=3 stride=2 pool='max'} srcLayers={"bn_conv1"};
    run;

    /* ------------------- Residual Layer 2A ----------------------- */
    
    /* res2a_branch1 layer: 256 channels, 1x1 conv, output = 56 x 56 */
    AddLayer/model='ResNet152' name="res2a_branch1" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"pool1"};
    run;

    /* res2a_branch1 batch norm layer: 256 channels, output = 56 x 56 */
    AddLayer/model='ResNet152' name="bn2a_branch1"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res2a_branch1"};
    run;

    /* res2a_branch2a layer: 64 channels, 1x1 conv, output = 56 x 56 */
    AddLayer/model='ResNet152' name="res2a_branch2a" 
            layer={type='convolution' nFilters=64 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"pool1"};
    run;

    /* res2a_branch2a batch norm layer: 64 channels, output = 56 x 56 */
    AddLayer/model='ResNet152' name="bn2a_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res2a_branch2a"};
    run;
    
    /* res2a_branch2b layer: 64 channels, 3x3 conv, output = 56 x 56 */
    AddLayer/model='ResNet152' name="res2a_branch2b" 
            layer={type='convolution' nFilters=64 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn2a_branch2a"};
    run;

    /* res2a_branch2b batch norm layer: 64 channels, output = 56 x 56 */
    AddLayer/model='ResNet152' name="bn2a_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res2a_branch2b"};
    run;

    /* res2a_branch2c layer: 256 channels, 1x1 conv, output = 56 x 56 */
    AddLayer/model='ResNet152' name="res2a_branch2c" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn2a_branch2b"};
    run;

    /* res2a_branch2c batch norm layer: 256 channels, output = 56 x 56 */
    AddLayer/model='ResNet152' name="bn2a_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res2a_branch2c"};
    run;
    
    /* res2a residual layer: 256 channels, output = 56 x 56 */
    AddLayer/model='ResNet152' name="res2a"
            layer={type='residual' act='RELU'} srcLayers={"bn2a_branch2c","bn2a_branch1"};
    run;
    
    /* ------------------- Residual Layer 2B ----------------------- */
    
    /* res2b_branch2a convolution layer: 64 channels, 1x1 conv, output = 56 x 56 */
    AddLayer/model='ResNet152' name="res2b_branch2a" 
            layer={type='convolution' nFilters=64 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res2a"};
    run;

    /* res2b_branch2a batch norm layer: 64 channels, output = 56 x 56 */
    AddLayer/model='ResNet152' name="bn2b_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res2b_branch2a"};
    run;

    /* res2b_branch2b convolution layer: 64 channels, 3x3 conv, output = 56 x 56 */
    AddLayer/model='ResNet152' name="res2b_branch2b" 
            layer={type='convolution' nFilters=64 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn2b_branch2a"};
    run;

    /* res2b_branch2b batch norm layer: 64 channels, output = 56 x 56 */
    AddLayer/model='ResNet152' name="bn2b_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res2b_branch2b"};
    run;
    
    /* res2b_branch2c layer: 256 channels, 1x1 conv, output = 56 x 56 */
    AddLayer/model='ResNet152' name="res2b_branch2c" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn2b_branch2b"};
    run;

    /* res2b_branch2c batch norm layer: 256 channels, output = 56 x 56 */
    AddLayer/model='ResNet152' name="bn2b_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res2b_branch2c"};
    run;
    
    /* res2b residual layer: 256 channels, output = 56 x 56 */
    AddLayer/model='ResNet152' name="res2b"
            layer={type='residual' act='RELU'} srcLayers={"res2a","bn2b_branch2c"};
    run;

    /* ------------------- Residual Layer 2C ----------------------- */
    
    /* res2c_branch2a convolution layer: 64 channels, 1x1 conv, output = 56 x 56 */
    AddLayer/model='ResNet152' name="res2c_branch2a" 
            layer={type='convolution' nFilters=64 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res2b"};
    run;

    /* res2c_branch2a batch norm layer: 64 channels, output = 56 x 56 */
    AddLayer/model='ResNet152' name="bn2c_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res2c_branch2a"};
    run;

    /* res2c_branch2b convolution layer: 64 channels, 3x3 conv, output = 56 x 56 */
    AddLayer/model='ResNet152' name="res2c_branch2b" 
            layer={type='convolution' nFilters=64 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn2c_branch2a"};
    run;

    /* res2c_branch2b batch norm layer: 64 channels, output = 56 x 56 */
    AddLayer/model='ResNet152' name="bn2c_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res2c_branch2b"};
    run;
    
    /* res2c_branch2c layer: 256 channels, 1x1 conv, output = 56 x 56 */
    AddLayer/model='ResNet152' name="res2c_branch2c" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn2c_branch2b"};
    run;

    /* res2c_branch2c batch norm layer: 256 channels, output = 56 x 56 */
    AddLayer/model='ResNet152' name="bn2c_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res2c_branch2c"};
    run;
    
    /* res2c residual layer: 256 channels, output = 56 x 56 */
    AddLayer/model='ResNet152' name="res2c"
            layer={type='residual' act='RELU'} srcLayers={"res2b","bn2c_branch2c"};
    run;
    
    /* ------------- Layer 3A -------------------- */
    
    /* res3a_branch1 layer: 512 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3a_branch1" 
            layer={type='convolution' nFilters=512 width=1 height=1 stride=2 noBias=TRUE act="IDENTITY"} srcLayers={"res2c"};
    run;

    /* res3a_branch1 batch norm layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3a_branch1"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res3a_branch1"};
    run;

    /* res3a_branch2a layer: 128 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3a_branch2a" 
            layer={type='convolution' nFilters=128 width=1 height=1 stride=2 noBias=TRUE act="IDENTITY"} srcLayers={"res2c"};
    run;

    /* res3a_branch2a batch norm layer: 128 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3a_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res3a_branch2a"};
    run;

    /* res3a_branch2b layer: 128 channels, 3x3 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3a_branch2b" 
            layer={type='convolution' nFilters=128 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn3a_branch2a"};
    run;

    /* res3a_branch2b batch norm layer: 128 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3a_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res3a_branch2b"};
    run;

    /* res3a_branch2c layer: 512 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3a_branch2c" 
            layer={type='convolution' nFilters=512 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn3a_branch2b"};
    run;

    /* res3a_branch2c batch norm layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3a_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res3a_branch2c"};
    run;
    
    /* res3a residual layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3a"
            layer={type='residual' act='RELU'} srcLayers={"bn3a_branch2c","bn3a_branch1"};
    run;
    
    /* ------------------- Residual Layer 3B1 ----------------------- */
    
    /* res3b1_branch2a convolution layer: 128 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b1_branch2a" 
            layer={type='convolution' nFilters=128 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res3a"};
    run;

    /* res3b1_branch2a batch norm layer: 128 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b1_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res3b1_branch2a"};
    run;

    /* res3b1_branch2b convolution layer: 128 channels, 3x3 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b1_branch2b" 
            layer={type='convolution' nFilters=128 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn3b1_branch2a"};
    run;

    /* res3b1_branch2b batch norm layer: 128 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b1_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res3b1_branch2b"};
    run;
    
    /* res3b1_branch2c layer: 512 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b1_branch2c" 
            layer={type='convolution' nFilters=512 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn3b1_branch2b"};
    run;

    /* res3b1_branch2c batch norm layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b1_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res3b1_branch2c"};
    run;
    
    /* res3b1 residual layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b1"
            layer={type='residual' act='RELU'} srcLayers={"res3a","bn3b1_branch2c"};
    run;
    
    /* ------------------- Residual Layer 3B2 ----------------------- */
    
    /* res3b2_branch2a convolution layer: 128 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b2_branch2a" 
            layer={type='convolution' nFilters=128 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res3b1"};
    run;

    /* res3b2_branch2a batch norm layer: 128 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b2_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res3b2_branch2a"};
    run;

    /* res3b2_branch2b convolution layer: 128 channels, 3x3 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b2_branch2b" 
            layer={type='convolution' nFilters=128 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn3b2_branch2a"};
    run;

    /* res3b2_branch2b batch norm layer: 128 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b2_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res3b2_branch2b"};
    run;
    
    /* res3b2_branch2c layer: 512 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b2_branch2c" 
            layer={type='convolution' nFilters=512 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn3b2_branch2b"};
    run;

    /* res3b2_branch2c batch norm layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b2_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res3b2_branch2c"};
    run;
    
    /* res3b2 residual layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b2"
            layer={type='residual' act='RELU'} srcLayers={"res3b1","bn3b2_branch2c"};
    run;

    /* ------------------- Residual Layer 3B3 ----------------------- */
    
    /* res3b3_branch2a convolution layer: 128 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b3_branch2a" 
            layer={type='convolution' nFilters=128 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res3b2"};
    run;

    /* res3b3_branch2a batch norm layer: 128 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b3_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res3b3_branch2a"};
    run;

    /* res3b3_branch2b convolution layer: 128 channels, 3x3 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b3_branch2b" 
            layer={type='convolution' nFilters=128 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn3b3_branch2a"};
    run;

    /* res3b3_branch2b batch norm layer: 128 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b3_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res3b3_branch2b"};
    run;
    
    /* res3b3_branch2c layer: 512 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b3_branch2c" 
            layer={type='convolution' nFilters=512 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn3b3_branch2b"};
    run;

    /* res3b3_branch2c batch norm layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b3_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res3b3_branch2c"};
    run;
    
    /* res3b3 residual layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b3"
            layer={type='residual' act='RELU'} srcLayers={"res3b2","bn3b3_branch2c"};
    run;

    /* ------------------- Residual Layer 3B4 ----------------------- */
    
    /* res3b4_branch2a convolution layer: 128 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b4_branch2a" 
            layer={type='convolution' nFilters=128 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res3b3"};
    run;

    /* res3b4_branch2a batch norm layer: 128 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b4_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res3b4_branch2a"};
    run;

    /* res3b4_branch2b convolution layer: 128 channels, 3x3 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b4_branch2b" 
            layer={type='convolution' nFilters=128 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn3b4_branch2a"};
    run;

    /* res3b4_branch2b batch norm layer: 128 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b4_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res3b4_branch2b"};
    run;
    
    /* res3b4_branch2c layer: 512 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b4_branch2c" 
            layer={type='convolution' nFilters=512 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn3b4_branch2b"};
    run;

    /* res3b4_branch2c batch norm layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b4_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res3b4_branch2c"};
    run;
    
    /* res3b4 residual layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b4"
            layer={type='residual' act='RELU'} srcLayers={"res3b3","bn3b4_branch2c"};
    run;

    /* ------------------- Residual Layer 3B5 ----------------------- */
    
    /* res3b5_branch2a convolution layer: 128 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b5_branch2a" 
            layer={type='convolution' nFilters=128 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res3b4"};
    run;

    /* res3b5_branch2a batch norm layer: 128 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b5_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res3b5_branch2a"};
    run;

    /* res3b5_branch2b convolution layer: 128 channels, 3x3 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b5_branch2b" 
            layer={type='convolution' nFilters=128 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn3b5_branch2a"};
    run;

    /* res3b5_branch2b batch norm layer: 128 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b5_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res3b5_branch2b"};
    run;
    
    /* res3b5_branch2c layer: 512 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b5_branch2c" 
            layer={type='convolution' nFilters=512 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn3b5_branch2b"};
    run;

    /* res3b5_branch2c batch norm layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b5_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res3b5_branch2c"};
    run;
    
    /* res3b5 residual layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b5"
            layer={type='residual' act='RELU'} srcLayers={"res3b4","bn3b5_branch2c"};
    run;

    /* ------------------- Residual Layer 3B6 ----------------------- */
    
    /* res3b6_branch2a convolution layer: 128 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b6_branch2a" 
            layer={type='convolution' nFilters=128 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res3b5"};
    run;

    /* res3b6_branch2a batch norm layer: 128 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b6_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res3b6_branch2a"};
    run;

    /* res3b6_branch2b convolution layer: 128 channels, 3x3 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b6_branch2b" 
            layer={type='convolution' nFilters=128 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn3b6_branch2a"};
    run;

    /* res3b6_branch2b batch norm layer: 128 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b6_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res3b6_branch2b"};
    run;
    
    /* res3b6_branch2c layer: 512 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b6_branch2c" 
            layer={type='convolution' nFilters=512 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn3b6_branch2b"};
    run;

    /* res3b6_branch2c batch norm layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b6_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res3b6_branch2c"};
    run;
    
    /* res3b6 residual layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b6"
            layer={type='residual' act='RELU'} srcLayers={"res3b5","bn3b6_branch2c"};
    run;

    /* ------------------- Residual Layer 3B7 ----------------------- */
    
    /* res3b7_branch2a convolution layer: 128 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b7_branch2a" 
            layer={type='convolution' nFilters=128 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res3b6"};
    run;

    /* res3b7_branch2a batch norm layer: 128 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b7_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res3b7_branch2a"};
    run;

    /* res3b7_branch2b convolution layer: 128 channels, 3x3 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b7_branch2b" 
            layer={type='convolution' nFilters=128 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn3b7_branch2a"};
    run;

    /* res3b7_branch2b batch norm layer: 128 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b7_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res3b7_branch2b"};
    run;
    
    /* res3b7_branch2c layer: 512 channels, 1x1 conv, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b7_branch2c" 
            layer={type='convolution' nFilters=512 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn3b7_branch2b"};
    run;

    /* res3b7_branch2c batch norm layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="bn3b7_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res3b7_branch2c"};
    run;
    
    /* res3b7 residual layer: 512 channels, output = 28 x 28 */
    AddLayer/model='ResNet152' name="res3b7"
            layer={type='residual' act='RELU'} srcLayers={"res3b6","bn3b7_branch2c"};
    run;
    
    /* ------------- Layer 4A -------------------- */
    
    /* res4a_branch1 layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4a_branch1" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=2 noBias=TRUE act="IDENTITY"} srcLayers={"res3b7"};
    run;

    /* res4a_branch1 batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4a_branch1"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4a_branch1"};
    run;

    /* res4a_branch2a layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4a_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=2 noBias=TRUE act="IDENTITY"} srcLayers={"res3b7"};
    run;

    /* res4a_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4a_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4a_branch2a"};
    run;

    /* res4a_branch2b layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4a_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4a_branch2a"};
    run;

    /* res4a_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4a_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4a_branch2b"};
    run;

    /* res4a_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4a_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4a_branch2b"};
    run;

    /* res4a_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4a_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4a_branch2c"};
    run;
    
    /* res4a residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4a"
            layer={type='residual' act='RELU'} srcLayers={"bn4a_branch2c","bn4a_branch1"};
    run;
    
    /* ------------------- Residual Layer 4B1 ----------------------- */
    
    /* res4b1_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b1_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4a"};
    run;

    /* res4b1_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b1_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b1_branch2a"};
    run;

    /* res4b1_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b1_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b1_branch2a"};
    run;

    /* res4b1_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b1_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b1_branch2b"};
    run;
    
    /* res4b1_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b1_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b1_branch2b"};
    run;

    /* res4b1_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b1_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b1_branch2c"};
    run;
    
    /* res4b1 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b1"
            layer={type='residual' act='RELU'} srcLayers={"res4a","bn4b1_branch2c"};
    run;

    /* ------------------- Residual Layer 4B2 ----------------------- */
    
    /* res4b2_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b2_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b1"};
    run;

    /* res4b2_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b2_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b2_branch2a"};
    run;

    /* res4b2_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b2_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b2_branch2a"};
    run;

    /* res4b2_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b2_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b2_branch2b"};
    run;
    
    /* res4b2_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b2_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b2_branch2b"};
    run;

    /* res4b2_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b2_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b2_branch2c"};
    run;
    
    /* res4b2 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b2"
            layer={type='residual' act='RELU'} srcLayers={"res4b1","bn4b2_branch2c"};
    run;
    
    /* ------------------- Residual Layer 4B3 ----------------------- */
    
    /* res4b3_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b3_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b2"};
    run;

    /* res4b3_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b3_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b3_branch2a"};
    run;

    /* res4b3_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b3_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b3_branch2a"};
    run;

    /* res4b3_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b3_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b3_branch2b"};
    run;
    
    /* res4b3_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b3_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b3_branch2b"};
    run;

    /* res4b3_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b3_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b3_branch2c"};
    run;
    
    /* res4b3 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b3"
            layer={type='residual' act='RELU'} srcLayers={"res4b2","bn4b3_branch2c"};
    run;

    /* ------------------- Residual Layer 4B4 ----------------------- */
    
    /* res4b4_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b4_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b3"};
    run;

    /* res4b4_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b4_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b4_branch2a"};
    run;

    /* res4b4_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b4_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b4_branch2a"};
    run;

    /* res4b4_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b4_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b4_branch2b"};
    run;
    
    /* res4b4_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b4_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b4_branch2b"};
    run;

    /* res4b4_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b4_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b4_branch2c"};
    run;
    
    /* res4b4 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b4"
            layer={type='residual' act='RELU'} srcLayers={"res4b3","bn4b4_branch2c"};
    run;

    /* ------------------- Residual Layer 4B5 ----------------------- */
    
    /* res4b5_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b5_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b4"};
    run;

    /* res4b5_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b5_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b5_branch2a"};
    run;

    /* res4b5_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b5_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b5_branch2a"};
    run;

    /* res4b5_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b5_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b5_branch2b"};
    run;
    
    /* res4b5_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b5_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b5_branch2b"};
    run;

    /* res4b5_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b5_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b5_branch2c"};
    run;
    
    /* res4b5 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b5"
            layer={type='residual' act='RELU'} srcLayers={"res4b4","bn4b5_branch2c"};
    run;

    /* ------------------- Residual Layer 4B6 ----------------------- */
    
    /* res4b6_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b6_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b5"};
    run;

    /* res4b6_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b6_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b6_branch2a"};
    run;

    /* res4b6_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b6_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b6_branch2a"};
    run;

    /* res4b6_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b6_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b6_branch2b"};
    run;
    
    /* res4b6_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b6_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b6_branch2b"};
    run;

    /* res4b6_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b6_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b6_branch2c"};
    run;
    
    /* res4b6 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b6"
            layer={type='residual' act='RELU'} srcLayers={"res4b5","bn4b6_branch2c"};
    run;

    /* ------------------- Residual Layer 4B7 ----------------------- */
    
    /* res4b7_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b7_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b6"};
    run;

    /* res4b7_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b7_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b7_branch2a"};
    run;

    /* res4b7_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b7_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b7_branch2a"};
    run;

    /* res4b7_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b7_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b7_branch2b"};
    run;
    
    /* res4b7_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b7_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b7_branch2b"};
    run;

    /* res4b7_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b7_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b7_branch2c"};
    run;
    
    /* res4b7 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b7"
            layer={type='residual' act='RELU'} srcLayers={"res4b6","bn4b7_branch2c"};
    run;

    /* ------------------- Residual Layer 4B8 ----------------------- */
    
    /* res4b8_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b8_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b7"};
    run;

    /* res4b8_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b8_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b8_branch2a"};
    run;

    /* res4b8_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b8_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b8_branch2a"};
    run;

    /* res4b8_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b8_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b8_branch2b"};
    run;
    
    /* res4b8_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b8_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b8_branch2b"};
    run;

    /* res4b8_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b8_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b8_branch2c"};
    run;
    
    /* res4b8 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b8"
            layer={type='residual' act='RELU'} srcLayers={"res4b7","bn4b8_branch2c"};
    run;

    /* ------------------- Residual Layer 4B9 ----------------------- */
    
    /* res4b9_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b9_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b8"};
    run;

    /* res4b9_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b9_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b9_branch2a"};
    run;

    /* res4b9_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b9_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b9_branch2a"};
    run;

    /* res4b9_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b9_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b9_branch2b"};
    run;
    
    /* res4b9_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b9_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b9_branch2b"};
    run;

    /* res4b9_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b9_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b9_branch2c"};
    run;
    
    /* res4b9 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b9"
            layer={type='residual' act='RELU'} srcLayers={"res4b8","bn4b9_branch2c"};
    run;

    /* ------------------- Residual Layer 4B10 ----------------------- */
    
    /* res4b10_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b10_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b9"};
    run;

    /* res4b10_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b10_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b10_branch2a"};
    run;

    /* res4b10_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b10_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b10_branch2a"};
    run;

    /* res4b10_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b10_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b10_branch2b"};
    run;
    
    /* res4b10_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b10_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b10_branch2b"};
    run;

    /* res4b10_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b10_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b10_branch2c"};
    run;
    
    /* res4b10 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b10"
            layer={type='residual' act='RELU'} srcLayers={"res4b9","bn4b10_branch2c"};
    run;
    
    /* ------------------- Residual Layer 4B11 ----------------------- */
    
    /* res4b11_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b11_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b10"};
    run;

    /* res4b11_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b11_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b11_branch2a"};
    run;

    /* res4b11_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b11_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b11_branch2a"};
    run;

    /* res4b11_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b11_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b11_branch2b"};
    run;
    
    /* res4b11_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b11_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b11_branch2b"};
    run;

    /* res4b11_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b11_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b11_branch2c"};
    run;
    
    /* res4b11 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b11"
            layer={type='residual' act='RELU'} srcLayers={"res4b10","bn4b11_branch2c"};
    run;

    /* ------------------- Residual Layer 4B12 ----------------------- */
    
    /* res4b12_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b12_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b11"};
    run;

    /* res4b12_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b12_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b12_branch2a"};
    run;

    /* res4b12_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b12_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b12_branch2a"};
    run;

    /* res4b12_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b12_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b12_branch2b"};
    run;
    
    /* res4b12_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b12_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b12_branch2b"};
    run;

    /* res4b12_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b12_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b12_branch2c"};
    run;
    
    /* res4b12 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b12"
            layer={type='residual' act='RELU'} srcLayers={"res4b11","bn4b12_branch2c"};
    run;

    /* ------------------- Residual Layer 4B13 ----------------------- */
    
    /* res4b13_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b13_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b12"};
    run;

    /* res4b13_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b13_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b13_branch2a"};
    run;

    /* res4b13_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b13_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b13_branch2a"};
    run;

    /* res4b13_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b13_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b13_branch2b"};
    run;
    
    /* res4b13_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b13_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b13_branch2b"};
    run;

    /* res4b13_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b13_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b13_branch2c"};
    run;
    
    /* res4b13 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b13"
            layer={type='residual' act='RELU'} srcLayers={"res4b12","bn4b13_branch2c"};
    run;

    /* ------------------- Residual Layer 4B14 ----------------------- */
    
    /* res4b14_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b14_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b13"};
    run;

    /* res4b14_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b14_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b14_branch2a"};
    run;

    /* res4b14_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b14_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b14_branch2a"};
    run;

    /* res4b14_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b14_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b14_branch2b"};
    run;
    
    /* res4b14_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b14_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b14_branch2b"};
    run;

    /* res4b14_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b14_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b14_branch2c"};
    run;
    
    /* res4b14 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b14"
            layer={type='residual' act='RELU'} srcLayers={"res4b13","bn4b14_branch2c"};
    run;

    /* ------------------- Residual Layer 4B15 ----------------------- */
    
    /* res4b15_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b15_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b14"};
    run;

    /* res4b15_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b15_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b15_branch2a"};
    run;

    /* res4b15_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b15_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b15_branch2a"};
    run;

    /* res4b15_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b15_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b15_branch2b"};
    run;
    
    /* res4b15_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b15_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b15_branch2b"};
    run;

    /* res4b15_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b15_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b15_branch2c"};
    run;
    
    /* res4b15 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b15"
            layer={type='residual' act='RELU'} srcLayers={"res4b14","bn4b15_branch2c"};
    run;

    /* ------------------- Residual Layer 4B16 ----------------------- */
    
    /* res4b16_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b16_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b15"};
    run;

    /* res4b16_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b16_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b16_branch2a"};
    run;

    /* res4b16_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b16_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b16_branch2a"};
    run;

    /* res4b16_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b16_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b16_branch2b"};
    run;
    
    /* res4b16_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b16_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b16_branch2b"};
    run;

    /* res4b16_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b16_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b16_branch2c"};
    run;
    
    /* res4b16 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b16"
            layer={type='residual' act='RELU'} srcLayers={"res4b15","bn4b16_branch2c"};
    run;

    /* ------------------- Residual Layer 4B17 ----------------------- */
    
    /* res4b17_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b17_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b16"};
    run;

    /* res4b17_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b17_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b17_branch2a"};
    run;

    /* res4b17_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b17_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b17_branch2a"};
    run;

    /* res4b17_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b17_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b17_branch2b"};
    run;
    
    /* res4b17_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b17_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b17_branch2b"};
    run;

    /* res4b17_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b17_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b17_branch2c"};
    run;
    
    /* res4b17 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b17"
            layer={type='residual' act='RELU'} srcLayers={"res4b16","bn4b17_branch2c"};
    run;

    /* ------------------- Residual Layer 4B18 ----------------------- */
    
    /* res4b18_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b18_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b17"};
    run;

    /* res4b18_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b18_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b18_branch2a"};
    run;

    /* res4b18_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b18_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b18_branch2a"};
    run;

    /* res4b18_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b18_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b18_branch2b"};
    run;
    
    /* res4b18_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b18_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b18_branch2b"};
    run;

    /* res4b18_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b18_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b18_branch2c"};
    run;
    
    /* res4b18 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b18"
            layer={type='residual' act='RELU'} srcLayers={"res4b17","bn4b18_branch2c"};
    run;

    /* ------------------- Residual Layer 4B19 ----------------------- */
    
    /* res4b19_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b19_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b18"};
    run;

    /* res4b19_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b19_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b19_branch2a"};
    run;

    /* res4b19_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b19_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b19_branch2a"};
    run;

    /* res4b19_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b19_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b19_branch2b"};
    run;
    
    /* res4b19_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b19_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b19_branch2b"};
    run;

    /* res4b19_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b19_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b19_branch2c"};
    run;
    
    /* res4b19 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b19"
            layer={type='residual' act='RELU'} srcLayers={"res4b18","bn4b19_branch2c"};
    run;

    /* ------------------- Residual Layer 4B20 ----------------------- */
    
    /* res4b20_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b20_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b19"};
    run;

    /* res4b20_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b20_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b20_branch2a"};
    run;

    /* res4b20_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b20_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b20_branch2a"};
    run;

    /* res4b20_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b20_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b20_branch2b"};
    run;
    
    /* res4b20_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b20_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b20_branch2b"};
    run;

    /* res4b20_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b20_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b20_branch2c"};
    run;
    
    /* res4b20 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b20"
            layer={type='residual' act='RELU'} srcLayers={"res4b19","bn4b20_branch2c"};
    run;

    /* ------------------- Residual Layer 4B21 ----------------------- */
    
    /* res4b21_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b21_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b20"};
    run;

    /* res4b21_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b21_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b21_branch2a"};
    run;

    /* res4b21_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b21_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b21_branch2a"};
    run;

    /* res4b21_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b21_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b21_branch2b"};
    run;
    
    /* res4b21_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b21_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b21_branch2b"};
    run;

    /* res4b21_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b21_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b21_branch2c"};
    run;
    
    /* res4b21 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b21"
            layer={type='residual' act='RELU'} srcLayers={"res4b20","bn4b21_branch2c"};
    run;

    /* ------------------- Residual Layer 4B22 ----------------------- */
    
    /* res4b22_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b22_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b21"};
    run;

    /* res4b22_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b22_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b22_branch2a"};
    run;

    /* res4b22_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b22_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b22_branch2a"};
    run;

    /* res4b22_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b22_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b22_branch2b"};
    run;
    
    /* res4b22_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b22_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b22_branch2b"};
    run;

    /* res4b22_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b22_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b22_branch2c"};
    run;
    
    /* res4b22 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b22"
            layer={type='residual' act='RELU'} srcLayers={"res4b21","bn4b22_branch2c"};
    run;

    /* ------------------- Residual Layer 4B23 ----------------------- */
    
    /* res4b23_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b23_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b22"};
    run;

    /* res4b23_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b23_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b23_branch2a"};
    run;

    /* res4b23_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b23_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b23_branch2a"};
    run;

    /* res4b23_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b23_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b23_branch2b"};
    run;
    
    /* res4b23_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b23_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b23_branch2b"};
    run;

    /* res4b23_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b23_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b23_branch2c"};
    run;
    
    /* res4b23 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b23"
            layer={type='residual' act='RELU'} srcLayers={"res4b22","bn4b23_branch2c"};
    run;

    /* ------------------- Residual Layer 4B24 ----------------------- */
    
    /* res4b24_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b24_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b23"};
    run;

    /* res4b24_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b24_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b24_branch2a"};
    run;

    /* res4b24_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b24_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b24_branch2a"};
    run;

    /* res4b24_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b24_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b24_branch2b"};
    run;
    
    /* res4b24_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b24_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b24_branch2b"};
    run;

    /* res4b24_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b24_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b24_branch2c"};
    run;
    
    /* res4b24 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b24"
            layer={type='residual' act='RELU'} srcLayers={"res4b23","bn4b24_branch2c"};
    run;

    /* ------------------- Residual Layer 4B25 ----------------------- */
    
    /* res4b25_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b25_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b24"};
    run;

    /* res4b25_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b25_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b25_branch2a"};
    run;

    /* res4b25_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b25_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b25_branch2a"};
    run;

    /* res4b25_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b25_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b25_branch2b"};
    run;
    
    /* res4b25_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b25_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b25_branch2b"};
    run;

    /* res4b25_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b25_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b25_branch2c"};
    run;
    
    /* res4b25 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b25"
            layer={type='residual' act='RELU'} srcLayers={"res4b24","bn4b25_branch2c"};
    run;

    /* ------------------- Residual Layer 4B26 ----------------------- */
    
    /* res4b26_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b26_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b25"};
    run;

    /* res4b26_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b26_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b26_branch2a"};
    run;

    /* res4b26_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b26_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b26_branch2a"};
    run;

    /* res4b26_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b26_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b26_branch2b"};
    run;
    
    /* res4b26_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b26_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b26_branch2b"};
    run;

    /* res4b26_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b26_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b26_branch2c"};
    run;
    
    /* res4b26 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b26"
            layer={type='residual' act='RELU'} srcLayers={"res4b25","bn4b26_branch2c"};
    run;

    /* ------------------- Residual Layer 4B27 ----------------------- */
    
    /* res4b27_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b27_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b26"};
    run;

    /* res4b27_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b27_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b27_branch2a"};
    run;

    /* res4b27_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b27_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b27_branch2a"};
    run;

    /* res4b27_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b27_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b27_branch2b"};
    run;
    
    /* res4b27_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b27_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b27_branch2b"};
    run;

    /* res4b27_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b27_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b27_branch2c"};
    run;
    
    /* res4b27 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b27"
            layer={type='residual' act='RELU'} srcLayers={"res4b26","bn4b27_branch2c"};
    run;

    /* ------------------- Residual Layer 4B28 ----------------------- */
    
    /* res4b28_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b28_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b27"};
    run;

    /* res4b28_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b28_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b28_branch2a"};
    run;

    /* res4b28_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b28_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b28_branch2a"};
    run;

    /* res4b28_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b28_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b28_branch2b"};
    run;
    
    /* res4b28_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b28_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b28_branch2b"};
    run;

    /* res4b28_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b28_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b28_branch2c"};
    run;
    
    /* res4b28 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b28"
            layer={type='residual' act='RELU'} srcLayers={"res4b27","bn4b28_branch2c"};
    run;

    /* ------------------- Residual Layer 4B29 ----------------------- */
    
    /* res4b29_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b29_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b28"};
    run;

    /* res4b29_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b29_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b29_branch2a"};
    run;

    /* res4b29_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b29_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b29_branch2a"};
    run;

    /* res4b29_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b29_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b29_branch2b"};
    run;
    
    /* res4b29_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b29_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b29_branch2b"};
    run;

    /* res4b29_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b29_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b29_branch2c"};
    run;
    
    /* res4b29 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b29"
            layer={type='residual' act='RELU'} srcLayers={"res4b28","bn4b29_branch2c"};
    run;

    /* ------------------- Residual Layer 4B30 ----------------------- */
    
    /* res4b30_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b30_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b29"};
    run;

    /* res4b30_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b30_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b30_branch2a"};
    run;

    /* res4b30_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b30_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b30_branch2a"};
    run;

    /* res4b30_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b30_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b30_branch2b"};
    run;
    
    /* res4b30_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b30_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b30_branch2b"};
    run;

    /* res4b30_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b30_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b30_branch2c"};
    run;
    
    /* res4b30 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b30"
            layer={type='residual' act='RELU'} srcLayers={"res4b29","bn4b30_branch2c"};
    run;

    /* ------------------- Residual Layer 4B31 ----------------------- */
    
    /* res4b31_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b31_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b30"};
    run;

    /* res4b31_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b31_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b31_branch2a"};
    run;

    /* res4b31_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b31_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b31_branch2a"};
    run;

    /* res4b31_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b31_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b31_branch2b"};
    run;
    
    /* res4b31_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b31_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b31_branch2b"};
    run;

    /* res4b31_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b31_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b31_branch2c"};
    run;
    
    /* res4b31 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b31"
            layer={type='residual' act='RELU'} srcLayers={"res4b30","bn4b31_branch2c"};
    run;

    /* ------------------- Residual Layer 4B32 ----------------------- */
    
    /* res4b32_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b32_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b31"};
    run;

    /* res4b32_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b32_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b32_branch2a"};
    run;

    /* res4b32_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b32_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b32_branch2a"};
    run;

    /* res4b32_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b32_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b32_branch2b"};
    run;
    
    /* res4b32_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b32_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b32_branch2b"};
    run;

    /* res4b32_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b32_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b32_branch2c"};
    run;
    
    /* res4b32 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b32"
            layer={type='residual' act='RELU'} srcLayers={"res4b31","bn4b32_branch2c"};
    run;

    /* ------------------- Residual Layer 4B33 ----------------------- */
    
    /* res4b33_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b33_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b32"};
    run;

    /* res4b33_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b33_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b33_branch2a"};
    run;

    /* res4b33_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b33_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b33_branch2a"};
    run;

    /* res4b33_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b33_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b33_branch2b"};
    run;
    
    /* res4b33_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b33_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b33_branch2b"};
    run;

    /* res4b33_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b33_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b33_branch2c"};
    run;
    
    /* res4b33 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b33"
            layer={type='residual' act='RELU'} srcLayers={"res4b32","bn4b33_branch2c"};
    run;

    /* ------------------- Residual Layer 4B34 ----------------------- */
    
    /* res4b34_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b34_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b33"};
    run;

    /* res4b34_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b34_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b34_branch2a"};
    run;

    /* res4b34_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b34_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b34_branch2a"};
    run;

    /* res4b34_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b34_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b34_branch2b"};
    run;
    
    /* res4b34_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b34_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b34_branch2b"};
    run;

    /* res4b34_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b34_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b34_branch2c"};
    run;
    
    /* res4b34 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b34"
            layer={type='residual' act='RELU'} srcLayers={"res4b33","bn4b34_branch2c"};
    run;

    /* ------------------- Residual Layer 4B35 ----------------------- */
    
    /* res4b35_branch2a convolution layer: 256 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b35_branch2a" 
            layer={type='convolution' nFilters=256 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res4b34"};
    run;

    /* res4b35_branch2a batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b35_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b35_branch2a"};
    run;

    /* res4b35_branch2b convolution layer: 256 channels, 3x3 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b35_branch2b" 
            layer={type='convolution' nFilters=256 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b35_branch2a"};
    run;

    /* res4b35_branch2b batch norm layer: 256 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b35_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res4b35_branch2b"};
    run;
    
    /* res4b35_branch2c layer: 1024 channels, 1x1 conv, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b35_branch2c" 
            layer={type='convolution' nFilters=1024 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn4b35_branch2b"};
    run;

    /* res4b35_branch2c batch norm layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="bn4b35_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res4b35_branch2c"};
    run;
    
    /* res4b35 residual layer: 1024 channels, output = 14 x 14 */
    AddLayer/model='ResNet152' name="res4b35"
            layer={type='residual' act='RELU'} srcLayers={"res4b34","bn4b35_branch2c"};
    run;
    
    /* ------------- Layer 5A -------------------- */
    
    /* res5a_branch1 layer: 2048 channels, 1x1 conv, output = 7 x 7 */
    AddLayer/model='ResNet152' name="res5a_branch1" 
            layer={type='convolution' nFilters=2048 width=1 height=1 stride=2 noBias=TRUE act="IDENTITY"} srcLayers={"res4b35"};
    run;

    /* res5a_branch1 batch norm layer: 2048 channels, output = 7 x 7 */
    AddLayer/model='ResNet152' name="bn5a_branch1"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res5a_branch1"};
    run;

    /* res5a_branch2a layer: 512 channels, 1x1 conv, output = 7 x 7 */
    AddLayer/model='ResNet152' name="res5a_branch2a" 
            layer={type='convolution' nFilters=512 width=1 height=1 stride=2 noBias=TRUE act="IDENTITY"} srcLayers={"res4b35"};
    run;

    /* res5a_branch2a batch norm layer: 512 channels, output = 7 x 7 */
    AddLayer/model='ResNet152' name="bn5a_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res5a_branch2a"};
    run;

    /* res5a_branch2b layer: 512 channels, 3x3 conv, output = 7 x 7 */
    AddLayer/model='ResNet152' name="res5a_branch2b" 
            layer={type='convolution' nFilters=512 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn5a_branch2a"};
    run;

    /* res5a_branch2b batch norm layer: 512 channels, output = 7 x 7 */
    AddLayer/model='ResNet152' name="bn5a_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res5a_branch2b"};
    run;

    /* res5a_branch2c layer: 2048 channels, 1x1 conv, output = 7 x 7 */
    AddLayer/model='ResNet152' name="res5a_branch2c" 
            layer={type='convolution' nFilters=2048 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn5a_branch2b"};
    run;

    /* res5a_branch2c batch norm layer: 2048 channels, output = 7 x 7 */
    AddLayer/model='ResNet152' name="bn5a_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res5a_branch2c"};
    run;
    
    /* res5a residual layer: 2048 channels, output = 7 x 7 */
    AddLayer/model='ResNet152' name="res5a"
            layer={type='residual' act='RELU'} srcLayers={"bn5a_branch2c","bn5a_branch1"};
    run;
    
    /* ------------------- Residual Layer 5B ----------------------- */
    
    /* res5b_branch2a convolution layer: 512 channels, 1x1 conv, output = 7 x 7 */
    AddLayer/model='ResNet152' name="res5b_branch2a" 
            layer={type='convolution' nFilters=512 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res5a"};
    run;

    /* res5b_branch2a batch norm layer: 512 channels, output = 7 x 7 */
    AddLayer/model='ResNet152' name="bn5b_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res5b_branch2a"};
    run;

    /* res5b_branch2b convolution layer: 512 channels, 3x3 conv, output = 7 x 7 */
    AddLayer/model='ResNet152' name="res5b_branch2b" 
            layer={type='convolution' nFilters=512 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn5b_branch2a"};
    run;

    /* res5b_branch2b batch norm layer: 512 channels, output = 7 x 7 */
    AddLayer/model='ResNet152' name="bn5b_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res5b_branch2b"};
    run;
    
    /* res5b_branch2c layer: 2048 channels, 1x1 conv, output = 7 x 7 */
    AddLayer/model='ResNet152' name="res5b_branch2c" 
            layer={type='convolution' nFilters=2048 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn5b_branch2b"};
    run;

    /* res5b_branch2c batch norm layer: 2048 channels, output = 7 x 7 */
    AddLayer/model='ResNet152' name="bn5b_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res5b_branch2c"};
    run;
    
    /* res5b residual layer: 2048 channels, output = 7 x 7 */
    AddLayer/model='ResNet152' name="res5b"
            layer={type='residual' act='RELU'} srcLayers={"res5a","bn5b_branch2c"};
    run;
    
    /* ------------------- Residual Layer 5C ----------------------- */
    
    /* res5c_branch2a convolution layer: 512 channels, 1x1 conv, output = 7 x 7 */
    AddLayer/model='ResNet152' name="res5c_branch2a" 
            layer={type='convolution' nFilters=512 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"res5b"};
    run;

    /* res5c_branch2a batch norm layer: 512 channels, output = 7 x 7 */
    AddLayer/model='ResNet152' name="bn5c_branch2a"
            layer={type='batchnorm' act='RELU'} srcLayers={"res5c_branch2a"};
    run;

    /* res5c_branch2b convolution layer: 512 channels, 3x3 conv, output = 7 x 7 */
    AddLayer/model='ResNet152' name="res5c_branch2b" 
            layer={type='convolution' nFilters=512 width=3 height=3 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn5c_branch2a"};
    run;

    /* res5c_branch2b batch norm layer: 512 channels, output = 7 x 7 */
    AddLayer/model='ResNet152' name="bn5c_branch2b"
            layer={type='batchnorm' act='RELU'} srcLayers={"res5c_branch2b"};
    run;
    
    /* res5c_branch2c layer: 2048 channels, 1x1 conv, output = 7 x 7 */
    AddLayer/model='ResNet152' name="res5c_branch2c" 
            layer={type='convolution' nFilters=2048 width=1 height=1 stride=1 noBias=TRUE act="IDENTITY"} srcLayers={"bn5c_branch2b"};
    run;

    /* res5c_branch2c batch norm layer: 2048 channels, output = 7 x 7 */
    AddLayer/model='ResNet152' name="bn5c_branch2c"
            layer={type='batchnorm' act='IDENTITY'} srcLayers={"res5c_branch2c"};
    run;
    
    /* res5c residual layer: 2048 channels, output = 7 x 7 */
    AddLayer/model='ResNet152' name="res5c"
            layer={type='residual' act='RELU'} srcLayers={"res5b","bn5c_branch2c"};
    run;
    
    /* ------------------- final layers ---------------------- */
    
    /* pool5 layer: 2048 channels, 7x7 pooling, output = 1 x 1 */
    AddLayer/model='ResNet152' name="pool5" 
            layer={type='pooling' width=7 height=7 stride=7 pool='mean'} srcLayers={"res5c"};
    run;
     
    /* fc1000 output layer: 1000 neurons */ /* NOTE: still need to set inverted dropout */
    AddLayer/model='ResNet152' name="fc1000"
             layer={type='output' n=1000 act="SOFTMAX"} srcLayers={"pool5"};
    run;
