﻿BuildModel/model={name='VGG16', replace=1} type = "CNN";
run;

/* input layer */
AddLayer/model='VGG16' name="data" 
         layer={type='input' nchannels=3 width=224 height=224 randomcrop='UNIQUE' offsets={103.939, 116.779, 123.68}};
run;

/* conv1_1 layer: 64*3*3 */
AddLayer/model='VGG16' name="conv1_1" 
        layer={type='convolution' nFilters=64 width=3 height=3 stride=1 act="RELU"} srcLayers={"data"};
run;

/* conv1_2 layer: 64*3*3 */
AddLayer/model='VGG16' name="conv1_2" 
        layer={type='convolution' nFilters=64 width=3 height=3 stride=1 act="RELU"} srcLayers={"conv1_1"};
run;

/* pool1 layer: 2*2 */
AddLayer/model='VGG16' name="pool1" 
        layer={type='pooling' width=2 height=2 stride=2 pool='max'} srcLayers={"conv1_2"};
run;

/* conv2_1 layer: 128*3*3 */
AddLayer/model='VGG16' name="conv2_1" 
        layer={type='convolution' nFilters=128 width=3 height=3 stride=1 act="RELU"} srcLayers={"pool1"};
run;

/* conv2_2 layer: 128*3*3 */
AddLayer/model='VGG16' name="conv2_2" 
        layer={type='convolution' nFilters=128 width=3 height=3 stride=1 act="RELU"} srcLayers={"conv2_1"};
run;

/* pool2 layer: 2*2 */
AddLayer/model='VGG16' name="pool2" 
        layer={type='pooling' width=2 height=2 stride=2 pool='max'} srcLayers={"conv2_2"};
run;

/* conv3_1 layer: 256*3*3 */
AddLayer/model='VGG16' name="conv3_1" 
        layer={type='convolution' nFilters=256 width=3 height=3 stride=1 act="RELU"} srcLayers={"pool2"};
run;

/* conv3_2 layer: 256*3*3 */
AddLayer/model='VGG16' name="conv3_2" 
        layer={type='convolution' nFilters=256 width=3 height=3 stride=1 act="RELU"} srcLayers={"conv3_1"};
run;

/* conv3_3 layer: 256*3*3 */
AddLayer/model='VGG16' name="conv3_3" 
        layer={type='convolution' nFilters=256 width=3 height=3 stride=1 act="RELU"} srcLayers={"conv3_2"};
run;

/* pool3 layer: 2*2 */
AddLayer/model='VGG16' name="pool3" 
        layer={type='pooling' width=2 height=2 stride=2 pool='max'} srcLayers={"conv3_3"};
run;

/* conv4_1 layer: 512*3*3 */
AddLayer/model='VGG16' name="conv4_1" 
        layer={type='convolution' nFilters=512 width=3 height=3 stride=1 act="RELU"} srcLayers={"pool3"};
run;

/* conv4_2 layer: 512*3*3 */
AddLayer/model='VGG16' name="conv4_2" 
        layer={type='convolution' nFilters=512 width=3 height=3 stride=1 act="RELU"} srcLayers={"conv4_1"};
run;

/* conv4_3 layer: 512*3*3 */
AddLayer/model='VGG16' name="conv4_3" 
        layer={type='convolution' nFilters=512 width=3 height=3 stride=1 act="RELU"} srcLayers={"conv4_2"};
run;

/* pool4 layer: 2*2 */
AddLayer/model='VGG16' name="pool4" 
        layer={type='pooling' width=2 height=2 stride=2 pool='max'} srcLayers={"conv4_3"};
run;

/* conv5_1 layer: 512*3*3 */
AddLayer/model='VGG16' name="conv5_1" 
        layer={type='convolution' nFilters=512 width=3 height=3 stride=1 act="RELU"} srcLayers={"pool4"};
run;

/* conv5_2 layer: 512*3*3 */
AddLayer/model='VGG16' name="conv5_2" 
        layer={type='convolution' nFilters=512 width=3 height=3 stride=1 act="RELU"} srcLayers={"conv5_1"};
run;

/* conv5_3 layer: 512*3*3 */
AddLayer/model='VGG16' name="conv5_3" 
        layer={type='convolution' nFilters=512 width=3 height=3 stride=1 act="RELU"} srcLayers={"conv5_2"};
run;

/* pool5 layer: 2*2 */
AddLayer/model='VGG16' name="pool5" 
        layer={type='pooling' width=2 height=2 stride=2 pool='max'} srcLayers={"conv5_3"};
run;

/* fc6 layer: 4096 neurons */ /* NOTE: still need to set inverted dropout */
AddLayer/model='VGG16' name="fc6"
         layer={type='fullconnect' n=4096 act="RELU" dropout=0.5} srcLayers={"pool5"};
run;

/* fc7 layer: 4096 neurons */ /* NOTE: still need to set inverted dropout */
AddLayer/model='VGG16' name="fc7"
         layer={type='fullconnect' n=4096 act="RELU" dropout=0.5} srcLayers={"fc6"};
run;

/* fc output layer: 1000 neurons */ /* NOTE: still need to set inverted dropout */
AddLayer/model='VGG16' name="fc8"
         layer={type='output' n=1000 act="SOFTMAX"} srcLayers={"fc7"};
run;
